Learn R Programming

avlm (version 0.1.0)

av.aov: Convert an aov Object to Anytime-Valid aov (avaov)

Description

Converts an object of class aov to an anytime-valid version by setting the precision parameter g as an attribute and updating the class.

Usage

# S3 method for aov
av(model, g = 1, ...)

Value

An object of class avaov with anytime-valid p-values.

Arguments

model

An aov object resulting from an ANOVA analysis.

g

An integer precision parameter for anytime-valid inference. Default is 1.

...

Additional arguments passed to or from other methods.