Learn R Programming

avlm (version 0.1.0)

summary.avlm: Summary Method for Anytime-Valid lm (avlm) Objects

Description

Computes a summary for an avlm object, a linear model enhanced with anytime-valid inference. In addition to the standard lm summary statistics, the p-values for the coefficient tests are recalculated using an anytime-valid method.

Usage

# S3 method for avlm
summary(object, ...)

Value

A summary object of class summary.avlm that includes updated p-values for the coefficients.

Arguments

object

An avlm object generated by av.lm.

...

Additional arguments passed to or from other methods.