Converts an object of class aov to an anytime-valid version by setting the
precision parameter g as an attribute and updating the class.
# S3 method for aov
av(model, g = 1, ...)An object of class avaov with anytime-valid p-values.
An aov object resulting from an ANOVA analysis.
An integer precision parameter for anytime-valid inference. Default is 1.
Additional arguments passed to or from other methods.