This method prints the summary of an avaov object. It captures the output
from the default printing method, substitutes the header "Pr(>F)" with "p value", and adds
a note indicating that anytime-valid inference is used.
# S3 method for summary.avaov
print(
x,
digits = max(3L, getOption("digits") - 3L),
signif.stars = getOption("show.signif.stars"),
...
)Invisibly returns the summary object.
An object of class summary.avaov.
The number of significant digits to use when printing. Defaults to a value based on options.
Logical indicating whether significance stars should be printed.
Additional arguments passed to or from other methods.