Computes a summary for an avlm object, a linear model enhanced with anytime-valid inference.
In addition to the standard lm summary statistics, the p-values for the coefficient tests are
recalculated using an anytime-valid method.
# S3 method for avlm
summary(object, ...)A summary object of class summary.avlm that includes updated p-values for the coefficients.
An avlm object generated by av.lm.
Additional arguments passed to or from other methods.